@@ -1,10 +1,11 @@
 #!/usr/bin/env python3
 import shlex
 import subprocess
+from machineconfig.cluster.sessions_managers.zellij_utils.monitoring_types import CommandStatus, ZellijSessionStatus, ComprehensiveStatus, ProcessInfo
 import psutil
 import random
 import string
-from typing import Dict, List, Optional, Any
+from typing import List, Optional
 from pathlib import Path
 import logging
 
@@ -12,6 +13,7 @@ from rich.console import Console
 
 from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig, TabConfig
 
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 console = Console()
@@ -34,7 +36,7 @@ class ZellijLayoutGenerator:
 """
 
     @staticmethod
-    def _generate_random_suffix(length: int = 8) -> str:
+    def _generate_random_suffix(length: int) -> str:
         """Generate a random string suffix for unique layout file names."""
         return "".join(random.choices(string.ascii_lowercase + string.digits, k=length))
 
@@ -68,7 +70,6 @@ class ZellijLayoutGenerator:
         tab_name = tab_config["tabName"]
         cwd = tab_config["startDir"]
         command = tab_config["command"]
-
         cmd, args = ZellijLayoutGenerator._parse_command(command)
         args_str = ZellijLayoutGenerator._format_args_for_kdl(args)
         tab_cwd = cwd or "~"
@@ -92,7 +93,7 @@ class ZellijLayoutGenerator:
             if not tab["startDir"].strip():
                 raise ValueError(f"Invalid startDir for tab '{tab['tabName']}': {tab['startDir']}")
 
-    def create_zellij_layout(self, layout_config: LayoutConfig, output_dir: Optional[str] = None, session_name: Optional[str] = None) -> str:
+    def create_zellij_layout(self, layout_config: LayoutConfig, output_dir: Optional[str], session_name: Optional[str]) -> str:
         ZellijLayoutGenerator._validate_layout_config(layout_config)
 
         # Enhanced Rich logging
@@ -114,7 +115,7 @@ class ZellijLayoutGenerator:
         layout_content += "\n}\n"
 
         try:
-            random_suffix = ZellijLayoutGenerator._generate_random_suffix()
+            random_suffix = ZellijLayoutGenerator._generate_random_suffix(8)
             if output_dir:
                 output_path = Path(output_dir)
                 output_path.mkdir(parents=True, exist_ok=True)
@@ -136,7 +137,7 @@ class ZellijLayoutGenerator:
             raise
 
     @staticmethod
-    def get_layout_preview(layout_config: LayoutConfig, layout_template: str | None = None) -> str:
+    def get_layout_preview(layout_config: LayoutConfig, layout_template: str | None) -> str:
         if layout_template is None:
             layout_template = """layout {
     default_tab_template {
@@ -154,7 +155,7 @@ class ZellijLayoutGenerator:
         return layout_content + "\n}\n"
 
     @staticmethod
-    def check_command_status(tab_name: str, layout_config: LayoutConfig) -> Dict[str, Any]:
+    def check_command_status(tab_name: str, layout_config: LayoutConfig) -> CommandStatus:
         # Find the tab with the given name
         tab_config = None
         for tab in layout_config["layoutTabs"]:
@@ -163,39 +164,181 @@ class ZellijLayoutGenerator:
                 break
 
         if tab_config is None:
-            return {"status": "unknown", "error": f"Tab '{tab_name}' not found in layout config", "running": False, "pid": None, "command": None, "cwd": None}
+            return {"status": "unknown", "error": f"Tab '{tab_name}' not found in layout config", "running": False, "command": "", "cwd": "", "tab_name": tab_name, "processes": []}
 
         command = tab_config["command"]
         cwd = tab_config["startDir"]
-        cmd, _ = ZellijLayoutGenerator._parse_command(command)
-
+        cmd, args = ZellijLayoutGenerator._parse_command(command)
         try:
-            # Look for processes matching the command
-            matching_processes = []
-            for proc in psutil.process_iter(["pid", "name", "cmdline", "status"]):
+            shells = {"bash", "sh", "zsh", "fish"}
+            matching_processes: list[ProcessInfo] = []
+            for proc in psutil.process_iter(["pid", "name", "cmdline", "status", "ppid", "create_time", "memory_info"]):
                 try:
-                    if proc.info["cmdline"] and len(proc.info["cmdline"]) > 0:
-                        # Check if the command matches
-                        if proc.info["name"] == cmd or cmd in proc.info["cmdline"][0] or any(cmd in arg for arg in proc.info["cmdline"]):
-                            matching_processes.append({"pid": proc.info["pid"], "name": proc.info["name"], "cmdline": proc.info["cmdline"], "status": proc.info["status"]})
-                except (psutil.NoSuchProcess, psutil.AccessDenied):
+                    info = proc.info
+                    proc_cmdline: list[str] | None = info.get("cmdline")  # type: ignore[assignment]
+                    if not proc_cmdline:
+                        continue
+                    if info.get("status") in ["zombie", "dead", "stopped"]:
+                        continue
+                    proc_name = info.get("name", "")
+                    is_match = False
+                    joined_cmdline = " ".join(proc_cmdline)
+                    # Primary matching heuristics - more precise matching
+                    if proc_name == cmd and cmd not in shells:
+                        # For non-shell commands, match if args appear in cmdline
+                        if not args or any(arg in joined_cmdline for arg in args):
+                            is_match = True
+                    elif proc_name == cmd and cmd in shells:
+                        # For shell commands, require more precise matching to avoid false positives
+                        if args:
+                            # Check if all args appear as separate cmdline arguments (not just substrings)
+                            args_found = 0
+                            for arg in args:
+                                for cmdline_arg in proc_cmdline[1:]:  # Skip shell name
+                                    if arg == cmdline_arg or (len(arg) > 3 and arg in cmdline_arg):
+                                        args_found += 1
+                                        break
+                            # Require at least as many args found as we're looking for
+                            if args_found >= len(args):
+                                is_match = True
+                    elif cmd in proc_cmdline[0] and cmd not in shells:
+                        # Non-shell command in first argument
+                        is_match = True
+
+                    # Additional shell wrapper filter - be more restrictive for shells
+                    if is_match and proc_name in shells and args:
+                        # For shell processes, ensure the match is actually meaningful
+                        # Don't match generic shell sessions just because they contain common paths
+                        meaningful_match = False
+                        for arg in args:
+                            # Only consider it meaningful if the arg is substantial (not just a common path)
+                            if len(arg) > 10 and any(arg == cmdline_arg for cmdline_arg in proc_cmdline[1:]):
+                                meaningful_match = True
+                                break
+                            # Or if it's an exact script name match
+                            elif arg.endswith(".py") or arg.endswith(".sh") or arg.endswith(".rb"):
+                                if any(arg in cmdline_arg for cmdline_arg in proc_cmdline[1:]):
+                                    meaningful_match = True
+                                    break
+                        if not meaningful_match:
+                            is_match = False
+                    if not is_match:
+                        continue
+                    try:
+                        proc_obj = psutil.Process(info["pid"])  # type: ignore[index]
+                        if proc_obj.status() not in ["running", "sleeping"]:
+                            continue
+                        mem_info = None
+                        try:
+                            mem = proc_obj.memory_info()
+                            mem_info = mem.rss / (1024 * 1024)
+                        except (psutil.NoSuchProcess, psutil.AccessDenied):
+                            pass
+                        matching_processes.append(
+                            {
+                                "pid": info["pid"],  # type: ignore[index]
+                                "name": proc_name,
+                                "cmdline": proc_cmdline,
+                                "status": info.get("status", "unknown"),
+                                "cmdline_str": joined_cmdline,
+                                "create_time": info.get("create_time", 0.0),
+                                **({"memory_mb": float(mem_info)} if mem_info is not None else {}),
+                            }
+                        )
+                    except (psutil.NoSuchProcess, psutil.AccessDenied):
+                        continue
+                except (psutil.NoSuchProcess, psutil.AccessDenied, psutil.ZombieProcess):
                     continue
 
-            if matching_processes:
-                return {"status": "running", "running": True, "processes": matching_processes, "command": command, "cwd": cwd, "tab_name": tab_name}
-            else:
-                return {"status": "not_running", "running": False, "processes": [], "command": command, "cwd": cwd, "tab_name": tab_name}
+            # Second-pass filtering: remove idle wrapper shells that have no meaningful (non-shell) descendants
+            filtered_active: list[ProcessInfo] = []
+            for proc_info in matching_processes:
+                try:
+                    proc_obj = psutil.Process(proc_info["pid"])  # type: ignore[index]
+                    if not proc_obj.is_running():
+                        continue
+                    status_val = proc_obj.status()
+                    if status_val not in ["running", "sleeping"]:
+                        continue
+                    proc_name = proc_info.get("name", "")
+                    if proc_name in shells:
+                        descendants = proc_obj.children(recursive=True)
+                        # Keep shell only if there exists a non-shell alive descendant OR descendant cmdline still includes our command token
+                        meaningful = False
+                        for child in descendants:
+                            try:
+                                if not child.is_running():
+                                    continue
+                                child_name = child.name()
+                                child_cmdline = " ".join(child.cmdline())
+                                if child_name not in shells:
+                                    meaningful = True
+                                    break
+                                if cmd in child_cmdline or any(arg in child_cmdline for arg in args):
+                                    meaningful = True
+                                    break
+                            except (psutil.NoSuchProcess, psutil.AccessDenied):
+                                continue
+                        if not meaningful:
+                            continue  # discard idle wrapper shell
+                    filtered_active.append(proc_info)
+                except (psutil.NoSuchProcess, psutil.AccessDenied, psutil.ZombieProcess):
+                    continue
+
+            if filtered_active:
+                # Heuristic: if the only remaining processes are wrapper shells invoking a script that already completed, mark as not running.
+                # Case: layout launches 'bash <script.sh>' where script finishes and leaves an idle shell whose cmdline still shows the script path.
+                try:
+                    if all(p.get("name") in shells for p in filtered_active):
+                        script_paths = [arg for arg in args if arg.endswith(".sh")]
+                        shell_only = True
+                        stale_script_overall = False
+                        for p in filtered_active:
+                            proc_shell = psutil.Process(p["pid"])  # type: ignore[index]
+                            create_time = getattr(proc_shell, "create_time", lambda: None)()
+                            cmdline_joined = " ".join(p.get("cmdline", []))
+                            stale_script = False
+                            for spath in script_paths:
+                                script_file = Path(spath)
+                                if script_file.exists():
+                                    try:
+                                        # If script mtime older than process start AND no non-shell descendants -> likely finished
+                                        if create_time and script_file.stat().st_mtime < create_time:
+                                            stale_script = True
+                                    except OSError:
+                                        pass
+                                if spath not in cmdline_joined:
+                                    stale_script = False
+                            # If shell has any alive non-shell descendants, treat as running
+                            descendants = proc_shell.children(recursive=True)
+                            for d in descendants:
+                                try:
+                                    if d.is_running() and d.name() not in shells:
+                                        shell_only = False
+                                        break
+                                except (psutil.NoSuchProcess, psutil.AccessDenied):
+                                    continue
+                            if not shell_only:
+                                break
+                            if stale_script:
+                                stale_script_overall = True
+                        if shell_only and stale_script_overall:
+                            return {"status": "not_running", "running": False, "processes": [], "command": command, "cwd": cwd, "tab_name": tab_name}
+                except Exception:
+                    pass
+                return {"status": "running", "running": True, "processes": filtered_active, "command": command, "cwd": cwd, "tab_name": tab_name}
+            return {"status": "not_running", "running": False, "processes": [], "command": command, "cwd": cwd, "tab_name": tab_name}
 
         except Exception as e:
             logger.error(f"Error checking command status for tab '{tab_name}': {e}")
-            return {"status": "error", "error": str(e), "running": False, "command": command, "cwd": cwd, "tab_name": tab_name}
+            return {"status": "error", "error": str(e), "running": False, "command": command, "cwd": cwd, "tab_name": tab_name, "processes": []}
 
-    def check_all_commands_status(self) -> Dict[str, Dict[str, Any]]:
+    def check_all_commands_status(self) -> dict[str, CommandStatus]:
         if not self.layout_config:
             logger.warning("No layout config tracked. Make sure to create a layout first.")
             return {}
 
-        status_report = {}
+        status_report: dict[str, CommandStatus] = {}
         for tab in self.layout_config["layoutTabs"]:
             tab_name = tab["tabName"]
             status_report[tab_name] = ZellijLayoutGenerator.check_command_status(tab_name, self.layout_config)
@@ -203,7 +346,7 @@ class ZellijLayoutGenerator:
         return status_report
 
     @staticmethod
-    def check_zellij_session_status(session_name: str) -> Dict[str, Any]:
+    def check_zellij_session_status(session_name: str) -> ZellijSessionStatus:
         try:
             # Run zellij list-sessions command
             result = subprocess.run(["zellij", "list-sessions"], capture_output=True, text=True, timeout=10)
@@ -214,22 +357,20 @@ class ZellijLayoutGenerator:
 
                 return {"zellij_running": True, "session_exists": session_running, "session_name": session_name, "all_sessions": sessions}
             else:
-                return {"zellij_running": False, "error": result.stderr, "session_name": session_name}
+                return {"zellij_running": False, "session_exists": False, "session_name": session_name, "all_sessions": [], "error": result.stderr}
 
         except subprocess.TimeoutExpired:
-            return {"zellij_running": False, "error": "Timeout while checking Zellij sessions", "session_name": session_name}
+            return {"zellij_running": False, "session_exists": False, "session_name": session_name, "all_sessions": [], "error": "Timeout while checking Zellij sessions"}
         except FileNotFoundError:
-            return {"zellij_running": False, "error": "Zellij not found in PATH", "session_name": session_name}
+            return {"zellij_running": False, "session_exists": False, "session_name": session_name, "all_sessions": [], "error": "Zellij not found in PATH"}
         except Exception as e:
-            return {"zellij_running": False, "error": str(e), "session_name": session_name}
+            return {"zellij_running": False, "session_exists": False, "session_name": session_name, "all_sessions": [], "error": str(e)}
 
-    def get_comprehensive_status(self) -> Dict[str, Any]:
+    def get_comprehensive_status(self) -> ComprehensiveStatus:
         zellij_status = ZellijLayoutGenerator.check_zellij_session_status(self.session_name or "default")
         commands_status = self.check_all_commands_status()
-
         running_count = sum(1 for status in commands_status.values() if status.get("running", False))
         total_count = len(commands_status)
-
         return {
             "zellij_session": zellij_status,
             "commands": commands_status,
@@ -306,16 +447,17 @@ class ZellijLayoutGenerator:
         console.print(Panel(summary_text, title="📊 Summary", style="blue"))
 
 
-def created_zellij_layout(layout_config: LayoutConfig, output_dir: Optional[str] = None) -> str:
+def created_zellij_layout(layout_config: LayoutConfig, output_dir: Optional[str]) -> str:
     generator = ZellijLayoutGenerator()
-    return generator.create_zellij_layout(layout_config, output_dir)
+    return generator.create_zellij_layout(layout_config, output_dir, None)
 
 
 def run_zellij_layout(layout_config: LayoutConfig):
-    layout_path = created_zellij_layout(layout_config)
+    layout_path = created_zellij_layout(layout_config, None)
     session_name = layout_config["layoutName"]
     try:
-        from machineconfig.cluster.sessions_managers.enhanced_command_runner import enhanced_zellij_session_start
+        from machineconfig.cluster.sessions_managers.utils.enhanced_command_runner import enhanced_zellij_session_start
+
         enhanced_zellij_session_start(session_name, layout_path)
     except ImportError:
         # Fallback to original implementation
@@ -352,8 +494,8 @@ if __name__ == "__main__":
     sample_layout: LayoutConfig = {
         "layoutName": "SampleBots",
         "layoutTabs": [
-            {"tabName": "🤖Bot1", "startDir": "~/code/bytesense/bithence", "command": "~/scripts/fire -mO go1.py bot1 --kw create_new_bot True"},
-            {"tabName": "🤖Bot2", "startDir": "~/code/bytesense/bithence", "command": "~/scripts/fire -mO go2.py bot2 --kw create_new_bot True"},
+            {"tabName": "🤖Bot1", "startDir": "~/code/bytesense/bithence", "command": "~/scripts/fire -mO go1.py bot1 -- --create_new_bot=True"},
+            {"tabName": "🤖Bot2", "startDir": "~/code/bytesense/bithence", "command": "~/scripts/fire -mO go2.py bot2 -- --create_new_bot=True"},
             {"tabName": "📊Monitor", "startDir": "~", "command": "htop"},
             {"tabName": "📝Logs", "startDir": "/var/log", "command": "tail -f /var/log/app.log"},
         ],
@@ -362,7 +504,7 @@ if __name__ == "__main__":
     try:
         # Create layout using the generator directly to access status methods
         generator = ZellijLayoutGenerator()
-        layout_path = generator.create_zellij_layout(sample_layout, session_name="test_session")
+        layout_path = generator.create_zellij_layout(sample_layout, None, "test_session")
         print(f"✅ Layout created successfully: {layout_path}")
 
         # Demonstrate status checking
