@@ -7,6 +7,7 @@ fire
 
 """
 
+from machineconfig.scripts.python.fire_jobs_route_helper import get_command_streamlit
 from machineconfig.scripts.python.helpers.helpers4 import search_for_files_of_interest
 from machineconfig.scripts.python.helpers.helpers4 import parse_pyfile
 from machineconfig.scripts.python.helpers.helpers4 import get_import_module_code
@@ -14,15 +15,13 @@ from machineconfig.utils.ve import get_ve_activate_line, get_ve_path_and_ipython
 from machineconfig.utils.options import choose_from_options
 from machineconfig.utils.path_helper import match_file_name, sanitize_path
 
-from machineconfig.utils.path_extended import PathExtended as PathExtended
+from machineconfig.utils.path_extended import PathExtended
 from machineconfig.utils.accessories import get_repo_root, randstr
 from machineconfig.scripts.python.fire_jobs_args_helper import FireJobArgs, extract_kwargs, parse_fire_args_from_context
 import platform
 from typing import Optional, Annotated
 from pathlib import Path
-import tomllib
 import typer
-# import os
 
 
 def route(args: FireJobArgs, fire_args: str = "") -> None:
@@ -86,73 +85,13 @@ def route(args: FireJobArgs, fire_args: str = "") -> None:
         choice_function = args.function
 
     if choice_file.suffix == ".py":
-        if args.streamlit:
-            import socket
-
-            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-            try:
-                s.connect(("8.8.8.8", 1))
-                local_ip_v4 = s.getsockname()[0]
-            except Exception:
-                local_ip_v4 = socket.gethostbyname(socket.gethostname())
-            finally:
-                s.close()
-            computer_name = platform.node()
-            port = 8501
-            toml_path: Optional[PathExtended] = None
-            toml_path_maybe = choice_file.parent.joinpath(".streamlit/config.toml")
-            if toml_path_maybe.exists():
-                toml_path = toml_path_maybe
-            elif choice_file.parent.name == "pages":
-                toml_path_maybe = choice_file.parent.parent.joinpath(".streamlit/config.toml")
-                if toml_path_maybe.exists():
-                    toml_path = toml_path_maybe
-            if toml_path is not None:
-                print(f"📄 Reading config.toml @ {toml_path}")
-                config = tomllib.loads(toml_path.read_text(encoding="utf-8"))
-                if "server" in config:
-                    if "port" in config["server"]:
-                        port = config["server"]["port"]
-                secrets_path = toml_path.with_name("secrets.toml")
-                if repo_root is not None:
-                    secrets_template_path = PathExtended.home().joinpath(f"dotfiles/creds/streamlit/{PathExtended(repo_root).name}/{choice_file.name}/secrets.toml")
-                    if args.environment != "" and not secrets_path.exists() and secrets_template_path.exists():
-                        secrets_template = tomllib.loads(secrets_template_path.read_text(encoding="utf-8"))
-                        if args.environment == "ip":
-                            host_url = f"http://{local_ip_v4}:{port}/oauth2callback"
-                        elif args.environment == "localhost":
-                            host_url = f"http://localhost:{port}/oauth2callback"
-                        elif args.environment == "hostname":
-                            host_url = f"http://{computer_name}:{port}/oauth2callback"
-                        else:
-                            host_url = f"http://{args.environment}:{port}/oauth2callback"
-                        try:
-                            secrets_template["auth"]["redirect_uri"] = host_url
-                            secrets_template["auth"]["cookie_secret"] = randstr(35)
-                            secrets_template["auth"]["auth0"]["redirect_uri"] = host_url
-                            # save_toml(obj=secrets_template, path=secrets_path)
-                        except Exception as ex:
-                            print(ex)
-                            raise ex
-            message = f"🚀 Streamlit app is running @:\n1- http://{local_ip_v4}:{port}\n2- http://{computer_name}:{port}\n3- http://localhost:{port}"
-            from rich.panel import Panel
-            from rich import print as rprint
-
-            rprint(Panel(message))
-            exe = f"streamlit run --server.address 0.0.0.0 --server.headless true --server.port {port}"
-            # exe = f"cd '{choice_file.parent}'; " + exe
-        elif args.interactive is False:
-            exe = "python"
-        elif args.jupyter:
-            exe = "jupyter-lab"
-        else:
-            exe = f"ipython -i --no-banner --profile {ipy_profile} "
-    elif choice_file.suffix == ".ps1" or choice_file.suffix == ".sh":
-        exe = "."
-    elif choice_file.suffix == "":
-        exe = ""
-    else:
-        raise NotImplementedError(f"File type {choice_file.suffix} not supported, in the sense that I don't know how to fire it.")
+        if args.streamlit:  exe = get_command_streamlit(choice_file, args.environment, repo_root)
+        elif args.interactive is False: exe = "python"
+        elif args.jupyter: exe = "jupyter-lab"
+        else: exe = f"ipython -i --no-banner --profile {ipy_profile} "
+    elif choice_file.suffix == ".ps1" or choice_file.suffix == ".sh": exe = "."
+    elif choice_file.suffix == "": exe = ""
+    else: raise NotImplementedError(f"File type {choice_file.suffix} not supported, in the sense that I don't know how to fire it.")
 
     if args.module or (args.debug and args.choose_function):  # because debugging tools do not support choosing functions and don't interplay with fire module. So the only way to have debugging and choose function options is to import the file as a module into a new script and run the function of interest there and debug the new script.
         assert choice_file.suffix == ".py", f"File must be a python file to be imported as a module. Got {choice_file}"
@@ -226,21 +165,10 @@ except ImportError as _ex:
         else:
             # command = f"cd {choice_file.parent}\n{exe} {choice_file.name}\ncd {PathExtended.cwd()}"
             command = f"{exe} {choice_file} "
-    if not args.cmd:
-        if "ipdb" in command:
-            command = f"pip install ipdb\n{command}"
-        if "pudb" in command:
-            command = f"pip install pudb\n{command}"
-        command = f"{activate_ve_line}\n{command}"
+    if not args.cmd: command = f"{activate_ve_line}\n{command}"
     else:
-        # CMD equivalent
-        if "ipdb" in command:
-            command = f"pip install ipdb & {command}"
-        if "pudb" in command:
-            command = f"pip install pudb & {command}"
         new_line = "\n"
         command = rf"""start cmd -Argument "/k {activate_ve_line.replace(".ps1", ".bat").replace(". ", "")} & {command.replace(new_line, " & ")} " """  # this works from powershell
-
     if args.submit_to_cloud:
         command = f"""
 {activate_ve_line}
@@ -251,39 +179,28 @@ python -m machineconfig.cluster.templates.cli_click --file {choice_file} """
     if args.Nprocess > 1:
         from machineconfig.cluster.sessions_managers.zellij_local import run_zellij_layout
         from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig
-
         layout: LayoutConfig = {"layoutName": "fireNprocess", "layoutTabs": []}
         for an_arg in range(args.Nprocess):
             layout["layoutTabs"].append({"tabName": f"tab{an_arg}", "startDir": str(PathExtended.cwd()), "command": f"uv run -m fire {choice_file} {choice_function} --idx={an_arg} --idx_max={args.Nprocess}"})
         run_zellij_layout(layout_config=layout)
         return None
-
     if args.optimized:
-        # note that in ipython, optimization is meaningless.
         command = command.replace("python ", "python -OO ")
-    # if platform.system() == "Linux":
-    #     command = "timeout 1s aafire -driver slang\nclear\n" + command
-
     from rich.panel import Panel
     from rich.console import Console
     from rich.syntax import Syntax
-
     console = Console()
-
     if args.zellij_tab is not None:
         comman_path__ = PathExtended.tmpfile(suffix=".sh")
         comman_path__.parent.mkdir(parents=True, exist_ok=True)
         comman_path__.write_text(command, encoding="utf-8")
         console.print(Panel(Syntax(command, lexer="shell"), title=f"🔥 fire command @ {comman_path__}: "), style="bold red")
         import subprocess
-
         existing_tab_names = subprocess.run(["zellij", "action", "query-tab-names"], capture_output=True, text=True, check=True).stdout.splitlines()
         if args.zellij_tab in existing_tab_names:
             print(f"⚠️ Tab name `{args.zellij_tab}` already exists. Please choose a different name.")
-            # args.zellij_tab = input("Please enter a new tab name: ")
             args.zellij_tab += f"_{randstr(3)}"
         from machineconfig.cluster.sessions_managers.zellij_local import run_command_in_zellij_tab
-
         command = run_command_in_zellij_tab(command=str(comman_path__), tab_name=args.zellij_tab, cwd=None)
     if args.watch:
         command = "watchexec --restart --exts py,sh,ps1 " + command
@@ -293,31 +210,19 @@ python -m machineconfig.cluster.templates.cli_click --file {choice_file} """
         if platform.system() in ["Linux", "Darwin"]:
             export_line = f"""export PYTHONPATH="{repo_root}""" + """:${PYTHONPATH}" """
         elif platform.system() == "Windows":
-            # export_line = f"""set PYTHONPATH="{repo_root}""" + """:%PYTHONPATH%" """
-            # powershell equivalent
             export_line = f"""$env:PYTHONPATH="{repo_root}""" + """:$env:PYTHONPATH" """
         else:
             raise NotImplementedError(f"Platform {platform.system()} not supported.")
         command = export_line + "\n" + command
-
-    # program_path = os.environ.get("op_script", None)
-    # program_path = PathExtended(program_path) if program_path is not None else PROGRAM_PATH
     if args.loop:
         if platform.system() in ["Linux", "Darwin"]:
             command = command + "\nsleep 0.5"
         elif platform.system() == "Windows":
-            # command = command + "timeout 0.5\n"
-            # pwsh equivalent
             command = "$ErrorActionPreference = 'SilentlyContinue';\n" + command + "\nStart-Sleep -Seconds 0.5"
         else:
             raise NotImplementedError(f"Platform {platform.system()} not supported.")
-        # command = command + f"\n. {program_path}"
-    console.print(Panel(Syntax(command, lexer="shell"), title=f"🔥 fire command @ {command}: "), style="bold red")
-    # program_path.parent.mkdir(parents=True, exist_ok=True)
-    # program_path.write_text(command, encoding="utf-8")
-    import subprocess
-
-    subprocess.run(command, shell=True, check=True)
+    from machineconfig.utils.code import run_script
+    run_script(command)
 
 
 def main(
